#
# spec file for package arkade
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           arkade
Version:        0.11.31
Release:        1.2
Summary:        Open Source Kubernetes Marketplace
License:        Apache-2.0
URL:            https://github.com/alexellis/arkade
Source:         arkade-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
arkade provides a portable marketplace for downloading your favourite devops
CLIs and installing helm charts, with a single command.  You can also download
CLIs like kubectl, kind, kubectx and helm faster than you can type
"apt-get/brew update".

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/alexellis/arkade/pkg.Version=v%{version} \
   -X github.com/alexellis/arkade/pkg.GitCommit=${COMMIT_HASH:0:8}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.31:
  * feat: add rclone, kubie & EKS-node-viewer
  * Add DNS server override for cert-manager
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.30:
  * feat: add openshift/rosa to tools
  * feat: retain tag format on chart upgrade
  * tests: add test for latest tag selection
  * fix: mitigate effect on tags of semVer
* Sat Oct 26 2024 opensuse_buildservice@ojkastl.de
- fix version output and zsh completion subpackage
- Update to version 0.11.29:
  * feat: add crossplane CLI (crank) to tools
  * Bump golang.org/x/crypto from 0.27.0 to 0.28.0
  * feat: add duplik8s to tools
  * refactor: consolidate version finding across version strategies
* Thu Oct 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.28:
  * Fix for docker-compose on arm64 Darwin
* Mon Sep 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.27:
  * feat: add labctl to tools
  * Make BINLOCATION configurable in get.sh
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.26:
  * fix: k0sctl binary name change & tests
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.25:
  * Enable override for cni download
  * Bump golang.org/x/crypto from 0.26.0 to 0.27.0
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.24:
  * amend kubetrim to access compressed binaries
  * Bump golang.org/x/mod from 0.20.0 to 0.21.0
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.23:
  * feat: add keploy to arkade
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.22:
  * Fix faulty tests merged via #1104 for keploy
  * feat: add keploy to arkade
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.21:
  * Update tool defintion for viddy
* Mon Aug 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.20:
  * Add kubetrim to README
  * Update go.mod
  * Add kubetrim by Alex Ellis
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.19:
  * Change upgradeable logic based on feedback
  * fix clusterawsadm after file pattern change
  * Move upgradeable check to using semVer/pre
  * Update deps in go.mod
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.18:
  * Revert "fix flyctl release name"
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.17:
  * Remove old apps and update to Go 1.22
  * Bump github.com/docker/docker
  * Bump golang.org/x/mod from 0.18.0 to 0.19.0
  * Bump github.com/sethvargo/go-password from 0.3.0 to 0.3.1
  * Bump golang.org/x/crypto from 0.24.0 to 0.25.0
  * Bump github.com/google/go-containerregistry from 0.19.2 to
    0.20.0
  * fix flyctl release name
  * Bump github.com/spf13/cobra from 1.8.0 to 1.8.1
  * Bump github.com/google/go-containerregistry from 0.19.1 to
    0.19.2
* Fri Jun 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.16:
  * Ignore latest tags in chart upgrade
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.15:
  * Fix tests
  * Add region for Hetzner for inlets-operator app
  * add support for lazydocker
  * Fix atuin due to rename of archive
  * add caddy system install
  * add caddy server as system install
  * add support of kubecolor binary
* Mon Jun 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.14:
  * Update support message variation
  * Rotate support message
  * update doctl tests to standard binary pattern
* Fri Jun  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.13:
  * Cause doctl to fail with 404 for armv7l
  * doctl: Resolve versions based on GitHub releases
  * repoint cmctl references to new github location
  * remove k10multicluster from downloads
  * add system install powershell
  * add better error handling
  * Add concurrency workers to chart/upgrade
  * Bump golang.org/x/mod from 0.17.0 to 0.18.0
  * Bump golang.org/x/crypto from 0.23.0 to 0.24.0
  * fix chart upgrade to handle v prefix
  * Add consul as a tool & fix tests
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.12:
  * Move Hashicorp tools to GH Version Strategy
  * Add kube-score to available tools
  * update readme tool table
  * add k8s version strategy
  * Fix issue which saw versions resolved twice
* Fri May 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.11:
  * update and add tests for stern
  * Bump golang.org/x/crypto from 0.22.0 to 0.23.0
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.10:
  * Fix clusterawsadm and cmctl CLI tools
  * Fix argo message and close body for node
  * Bump github.com/sethvargo/go-password from 0.2.0 to 0.3.0
  * Bump golang.org/x/crypto from 0.21.0 to 0.22.0
  * Bump golang.org/x/mod from 0.16.0 to 0.17.0
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.9:
  * update minio chart location to bitnami
  * Update kubectl version
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.8:
  * add support for faasd
* Wed Apr 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.7:
  * add support for regctl
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.6:
  * Add OpenTofu
  * Bump github.com/google/go-containerregistry from 0.19.0 to
    0.19.1
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.5:
  * update versions of tf / packer / waypoint
  * Bump alexellis/upload-assets from 0.4.0 to 0.4.1
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.4:
  * PR #1036 Add terraform-docs by @cyberox
  * PR #1038 Bump golang.org/x/mod from 0.15.0 to 0.16.0 by
    @dependabot[bot]
  * PR #1037 Bump golang.org/x/crypto from 0.19.0 to 0.21.0 by
    @dependabot[bot]
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.3:
  * PR #1027 Bump golang.org/x/mod from 0.14.0 to 0.15.0 by
    @dependabot[bot]
  * PR #992 feat: allow to set default ingressclass by @Jasstkn
  * PR #1025 Bump github.com/cheggaaa/pb/v3 from 3.1.4 to 3.1.5 by
    @dependabot[bot]
  * PR #1028 Bump golang.org/x/crypto from 0.18.0 to 0.19.0 by
    @dependabot[bot]
  * PR #1007 change kubectl download site by @YoninL
  * PR #1022 chore: no need to use fmt.Sprintf by @testwill
  * PR #1019 Add tflint by @cyberox
  * PR #1033 feat: add gptscript as cli by @dirien
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.2:
  * Aliases for OCI
  * Correct help message
  * Fix croc file pattern & e2e test
  * Remove misc log file
* Wed Feb 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.1:
  * helm: add arkade chart bump to bump chart versions
  * feat: support tilt since 0.33.15
* Tue Feb 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.11.0:
  * Add oci extract command
  * Bump github.com/google/go-containerregistry from 0.17.0 to
    0.19.0
  * add support of cloud-hypervisor and ch-remote binary
  * Fix arkade get for kail on darwin&arm64
  * Bump golang.org/x/crypto from 0.17.0 to 0.18.0
  * Use Go 1.21 for e2e checker
  * Limit builds for same SHA
  * Move to Go 1.21 for builds and minimum version
* Thu Feb  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.10.20:
  * Bump golang.org/x/crypto from 0.16.0 to 0.17.0
* Fri Dec 15 2023 kastl@b1-systems.de
- Update to version 0.10.19:
  * Fix issue with version flag for Helm charts
* Tue Dec 12 2023 kastl@b1-systems.de
- Update to version 0.10.18:
  * Bump go.mod and vendor
  * Export LoadFrom
  * Update README.md
  * Bump actions/setup-go from 4 to 5
* Tue Dec  5 2023 kastl@b1-systems.de
- Update to version 0.10.17:
  * Add rgee/snowmachine for the festive period
  * Bump github.com/google/go-containerregistry from 0.16.1 to
    0.17.0
  * Bump golang.org/x/crypto from 0.15.0 to 0.16.0
* Tue Nov 28 2023 kastl@b1-systems.de
- Update to version 0.10.16:
  * Update system go installation for new format
  * feat: add kwokctl to arkade get tools
  * feat: add kwok to arkade get tools
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0
  * Bump golang.org/x/mod from 0.13.0 to 0.14.0
  * Bump golang.org/x/crypto from 0.14.0 to 0.15.0
* Fri Nov 10 2023 kastl@b1-systems.de
- Update to version 0.10.15:
  * Fix for regex for downloading Node.js
  * Add demo gif and vhs tape file
  * Bump golang.org/x/mod from 0.12.0 to 0.13.0
  * Bump golang.org/x/crypto from 0.13.0 to 0.14.0
  * Bump github.com/alexellis/go-execute/v2 from 2.1.0 to 2.2.1
  * Bump github.com/otiai10/copy from 1.12.0 to 1.14.0
* Fri Nov 10 2023 kastl@b1-systems.de
- Update to version 0.10.14:
  * feat: add kube-linter tool
* Wed Oct  4 2023 kastl@b1-systems.de
- Update to version 0.10.13:
  * Fix chart-upgrade as a result of yaml library upgrade
* Wed Oct  4 2023 kastl@b1-systems.de
- Update to version 0.10.12:
  * feat: update openfaas-loki to use new OCI repository
* Mon Oct  2 2023 kastl@b1-systems.de
- Update to version 0.10.11:
  * Fix issue with new version of go-execute
  * Disable update for windows for the time being
* Fri Sep 29 2023 kastl@b1-systems.de
- Update to version 0.10.10:
  * Remove temporary files after downloading binaries
* Fri Sep 29 2023 kastl@b1-systems.de
- Update to version 0.10.9:
  * Fix #117
  * Update to v3 of YAML package
  * Initial version of an update-sdk
  * go mod tidy
* Fri Sep 29 2023 kastl@b1-systems.de
- Update to version 0.10.8:
  * Alteration to support message
  * Enable force flag, and add documentation to command
  * Make digest verification optional
  * Download and verify SHA digest
  * Enable self-update for arkade
  * Update Kafka connector to use brokerHosts
* Fri Sep 15 2023 kastl@b1-systems.de
- Update to version 0.10.7:
  * Fix typo in test
  * Update vendor
  * Update to v2 of go-execute
* Thu Sep 14 2023 kastl@b1-systems.de
- Update to version 0.10.6:
  * Fix Windows template for K9s
* Thu Sep 14 2023 kastl@b1-systems.de
- Update to version 0.10.5:
  * Fix jq executable name for release 1.7
* Thu Sep 14 2023 kastl@b1-systems.de
- Update to version 0.10.4:
  * Inline errors
  * Force helm repo to be added if it exists
* Wed Sep 13 2023 kastl@b1-systems.de
- Update to version 0.10.3:
  * Fix tests for VHS
  * Fix for VHS URLs for Darwin
* Wed Sep 13 2023 kastl@b1-systems.de
- Update to version 0.10.2:
  * Fix gh CLI for Darwin
  * Bump golang.org/x/crypto from 0.12.0 to 0.13.0
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.10.1:
  * add skupper
* Tue Sep  5 2023 kastl@b1-systems.de
- BuildRequire go1.20
- Update to version 0.10.0:
  * Fix viddy failing app
  * Ignore gofmt errors from vendor folder
  * Update vendor
  * Update Go dependencies
  * Build with Go 1.20
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.9.27:
  * Add note on actuated
  * add vhs to arkade get
  * Uncommenting kubestr as issue #160 is resolved due to binaries
    becoming available once more
  * Bump golang.org/x/crypto from 0.10.0 to 0.11.0
  * Corrected to reflect the new url for the atuin project
* Tue Aug  1 2023 kastl@b1-systems.de
- Update to version 0.9.26:
  * Add etcd CLI to arkade
* Wed Jul 26 2023 kastl@b1-systems.de
- Update to version 0.9.25:
  * Comment out kubestr due to invalid release
  * Fix tests for new K0s format
  * Add test for existing K0s app
  * Bump github.com/cheggaaa/pb/v3 from 3.1.2 to 3.1.4
  * update readme
  * fix eksctl installation & tests
  * fix tests for kubens
  * fix helm for darwin arm
* Thu Jul  6 2023 kastl@b1-systems.de
- Update to version 0.9.24:
  * Bump golang.org/x/mod from 0.11.0 to 0.12.0
  * Fix kube-burner
  * Fix renamed org for sops
* Thu Jun 29 2023 kastl@b1-systems.de
- Update to version 0.9.23:
  * unblock installs on arm64 nodes
  * Add 1password and task CLIs to arkage get
  * Bump github.com/otiai10/copy from 1.11.0 to 1.12.0
  * update chart url
  * permit postgresql install on arm64
  * Bump golang.org/x/mod from 0.10.0 to 0.11.0
  * fix format
  * shorten name
  * add binaryBase optional field
  * update inletsctl unit test
  * fix: linux aarch64
  * Update tools.go
  * Bump golang.org/x/crypto from 0.9.0 to 0.10.0
  * Add extra notes for test-tool.sh
  * Add test tool note to PR template
  * Update Kustomize to v5.0.3 and support Windows
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.9.22:
  * Remove duplicate cilium tool and add unit test
  * Add failing test to find duplicate tools
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.9.21:
  * Add cilium CLI to arkade
  * add copa to arkade get
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.9.20:
  * feat: add atuin shell history tool and update catalog of CLIs
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.9.19:
  * add openshift tools
  * Update README.md
  * add buildkitd and gitlab-runner to system-install in README.md
  * add kube-burner
  * Fixes #918 move from stedolan/jq to jqlang/jq
  * fix: add ming to clusterctl
* Tue Jun 13 2023 kastl@b1-systems.de
- Update to version 0.9.18:
  * Add example into README and edit pull request template
  * Download binaries to separate temp directory
  * remove arch 386 for arkade get helmfile
  * add buildkitd to system install
  * add replicated-cli to arkade get
  * Bump github.com/docker/distribution
  * Bump github.com/otiai10/copy from 1.10.0 to 1.11.0
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.9.17:
  * add system install for gitlab runner
  * Bump github.com/google/go-containerregistry from 0.14.0 to
    0.15.2
  * Bump golang.org/x/crypto from 0.8.0 to 0.9.0
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.9.16:
  * Fix issue with inlets-operator secret creation
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.9.15:
  * Update metal CLI version
- 0.9.14 is not existing, same commit hash as 0.9.13
* Mon Apr 17 2023 kastl@b1-systems.de
- Update to version 0.9.13:
  * Update version for metrics-server
  * bump linkerd
  * Add kyverno CLI
  * Remove ioutil usage
  * Fix command info
  * Remove background from image using Gimp
  * Clarify how Derek works with DCO sign-off messages
* Mon Apr 17 2023 kastl@b1-systems.de
- Update to version 0.9.12:
  * Fix test for kubens
  * Update kubectl, terraform and remove version for kubens
  * Bump github.com/otiai10/copy from 1.9.0 to 1.10.0
  * enable support for seaweedfs
  * Update ISSUE_TEMPLATE.md
  * Bump golang.org/x/crypto from 0.7.0 to 0.8.0
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.9.11:
  * Fix test-tool.sh for Windows
  * Add Timoni CLI Timoni is a package manager for Kubernetes
    powered by CUE.
  * Update PULL_REQUEST_TEMPLATE.md
  * Update ISSUE_TEMPLATE.md
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.9.10:
  * Add youtube-dl
  * Update README.md
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.9.9:
  * Bump golang.org/x/mod from 0.9.0 to 0.10.0
  * Bump github.com/spf13/cobra from 1.6.1 to 1.7.0
  * Update go.mod to 1.19
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.9.8:
  * Add Darwin / M1 option for faas-cli
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.9.7:
  * Sort apps by name in --print-table
  * Update README.md
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.9.6:
  * Add cmctl to README
  * Add cmctl
  * Update README
  * Add actions-usage CLI
  * Add fstail, remove cnpg
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.9.5:
  * Add tool: actuated-cli
  * Update test-tool.sh
  * Bump actions/setup-go from 3 to 4
  * Bump github.com/google/go-containerregistry from 0.13.0 to
    0.14.0
  * Remove url from output of arkade get -o table|list
  * Adding cnpg to README and quick links to catalogs
  * chore: add cnpg plugin for kubectl
  * Bump golang.org/x/crypto from 0.6.0 to 0.7.0
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.9.4:
  * Fix issue with kubeseal releases
  * Fix #866
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.9.3:
  * Fix issue in secret literals in inlets-operator app
  * Bump github.com/cheggaaa/pb/v3 from 3.1.0 to 3.1.2
  * Update test-tool.sh readability
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.9.2:
  * Fix issue with inlets-pro binary for M1
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.9.1:
  * Trim installation text
  * Install CRD from chart
  * Create inlets license secret in K8s
  * Update CRD URL for inlets-operator app
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.9.0:
  * Create meaningful next action for missing tools
  * Add user-agent to all HTTP requests
  * UX: print human-readable error in case of 404
  * add croc cli
  * Update README.md
  * Bump golang.org/x/crypto from 0.5.0 to 0.6.0
  * Bump golang.org/x/mod from 0.7.0 to 0.8.0
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.62:
  * feat: add project's link in the markdown format for list of
    tools
  * Broken sponsors link
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.61:
  * Grafana agent changed its download URL
  * clusterawsadm: rm ming/arm64 test
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.60:
  * add clusterawsadm
  * add eksctl-anywhere
  * Fix k9s install, template name, upd contributing.md
  * Smaller image for Everyday Golang
  * Remove matrix from GHA
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.59:
  * Add grype to arkade get
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.58:
  * add syft to arkade get
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.57:
  * Fix tool for devspace
  * Bump github.com/google/go-containerregistry from 0.12.1
    to 0.13.0
  * Upgrade Istio version in app
  * Replace outdated tiller reference with helm reference
  * Amend ming entries following review comments
  * Add v prefix to VersionNumber for kail
  * Fix krew on Apple silicon
  * Bump golang.org/x/crypto from 0.4.0 to 0.5.0
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.56:
  * fix: handle "v" prefix on image tags when upgrading
  * Update stats
  * Swap image out for eBook link
  * Update ToC for Helm features
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.55:
  * feat: Upgrade container images within YAML files
  * Add support of scaleway-cli
  * Switch to GitHub for looking up Helm version dynamically
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.54:
  * Update Helm version
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.53:
  * Unpin the version of Helm used
  * Fix dashboard flag for OpenFaaS app
  * Add jetstream flag to OpenFaaS app
  * Bump github.com/otiai10/copy from 1.7.1 to 1.9.0
  * Bump golang.org/x/mod from 0.6.0 to 0.7.0
  * Bump github.com/google/go-containerregistry from 0.12.0
    to 0.12.1
  * support grafana agent
  * Remove artificats from tmp
  * Update README.md
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.52:
  * Bump github actions to go1.19
  * Add code for hostctl on Apple silicon
  * Add support for registry component
  * Bump golang.org/x/crypto from 0.1.0 to 0.4.0
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.51:
  * Bump github.com/otiai10/copy from 1.7.0 to 1.7.1
  * Add support for firectl
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.50:
  * Update publish.yml
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.49:
  * Support reading non gzip-compressed tar files
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.48:
  * Bump github.com/google/go-containerregistry from 0.11.0
    to 0.12.0
  * Bump github.com/spf13/cobra from 1.5.0 to 1.6.1
  * Fix argocd for darwin arm
  * Add tctl to arkade get
  * Fix missing WithHelmUpdateRepo
  * add support of viddy
  * Fix tc-redirect-tap system app for arm64
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.47:
  * Add google crane to arkade
  * Add kubeconform, conftest, kubeval tools
  * Mention GH action
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.46:
  * Fix rabbitmq installation message
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.45:
  * Add tc-redirect-tap system app
  * Update Grafana helm chart version
  * Less is more
* Sun Mar  5 2023 kastl@b1-systems.de
- Update to version 0.8.44:
  * Add inlets/mixctl
  * Update kubectl version to v1.24
  * add flyctl tool
  * Update PULL_REQUEST_TEMPLATE.md
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.43:
  * Update docker registry to twun.io's registry chart
  * Extract key generation into separate function
  * Move flag checks to PreRun
  * Improve app for OpenFaaS Pro
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.42:
  * Add run-job tool to arkade
  * Remove hacktoberfest feature from Derek file
  * Add @Jasstkn and @nitishkumar71 to Derek
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.41:
  * Enable image verification upto Max Level
  * Add butane tool to arkade
  * Fix arkade get helmfile for Mac ARM, update owner repo
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.40:
  * Fix arkade get sops for Mac ARM
  * Don't print support message in quiet mode
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.39:
  * Add hadolint tool
  * Fix kubecm download and e2e tests
  * Bump github.com/docker/go-units from 0.4.0 to 0.5.0
  * Update the contributing guide and rename dagger-test.sh
  * Add chart-releaser tool
  * passing missing parameter for tool.GetURL
  * Adding operator-sdk to list of tools
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.38:
  * Remove expired sponsored apps from Venafi and Kasten
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.37:
  * Document chart verify command
  * Add command to verify chart images
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.36:
  * Update support message
  * Update CODEOWNERS
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.35:
  * Add vault to list of tools
  * chore: update helm version to v3.9.3
  * Add vault to list of apps
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.34:
  * Fix installation of cni system app on armv7
  * Fix buildx arm64 binary download for linux and darwin
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.33:
  * Add Redpanda's rpk tool to arakde get
  * Add lazygit to list of tools
  * feat: add Bun to tools
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.32:
  * Add golangci-lint to list of tools
  * Update CONTRIBUTING.md
  * Update README quotes
  * Update intro
  * Add Kiran's article
  * Add terrascan via #499
  * Add talosctl as a new CLI tool.
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.31:
  * Update output message and regenerate app table
  * Add app for qemu-static
  * Add promtool as a new CLI tool
  * Update the mongodb app to use the bitnami chart
  * Add just as an installable cli tool
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.30:
  * Add gomplate to `arkade get`
  * Bump github.com/cheggaaa/pb/v3 from 3.0.8 to 3.1.0
  * Update kubernetes dashboard
  * Update NFS client helm chart
  * Add Hubble CLI to arkade get
  * Update sealed secrets helm chart
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.29:
  * Extend timeout for VPN users
  * Upgrade to Go 1.18 for CI and 1.17 for modules
  * feat: add nodejs to system install
  * Refresh list of Kubernetes apps
  * Add fzf tool
  * Fix warning about printing extra newlines
  * removed version
  * adds terragrunt
  * Bump hashicrop tool versions
  * Remove duplicate code for kumactl
  * Add Cilium CLI to arkade get
  * Replace `cmd.mergeFlags` with `config.MergeFlags` - Fix multiple equal sing handling for values in `config.MergeFlags` with tests - Add start-end single quote removal to `config.MergeFlags` with tests - Remove old `cmd.mergeFlags`
  * Add nats-server binary
  * Bump github.com/spf13/cobra from 1.4.0 to 1.5.0
  * Increase tools test coverage
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.28:
  * Update key for OpenFaaS Pro in helm chart values
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.27:
  * Add M1 version for minikube
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.26:
  * Fix disabling progress for go and actions runner packages
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.25:
  * Add the GitHub Actions runner to the README
  * Add GitHub Actions Runner as system package
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.24:
  * Add caddy server to `arkade get`
  * Fix get.sh for CentOS9
  * Revise intro
  * Update README intro
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.23:
  * Update thanks message to support message
  * Document system packages
  * Add containerd for system applications.
  * Bump actions/setup-go from 2 to 3
  * Use read/write/execute everyone for system packages
  * Amend style of Prometheus app
  * Add CNI plugins as system package
  * feat: add arch flag to prometheus install
  * Replace all hardcoded arch strings with variable
  * feat: add prometheus install
  * Change eksctl's versioning to dynamic by moving from url template to binary template
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.22:
  * feat: add firecracker install
  * Fix the arch check of terraform in Mac M1 environment
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.21:
  * Fix template for hey for darwin/arm64
  * Add back @alexellis's hey fork
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.20:
  * Clarify difference between untar code
  * Add system apps top-level command and Go package
  * Fix the arch check of jq in Mac M1 environment
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.19:
  * Remove duplicate kumactl test
  * Add `kumactl` to installable tools with e2e skip
  * feat(tools): add oh-my-posh
  * Add Kuma mesh to installable apps
  * Add `kumactl` to installable tools with e2e skip
  * Update ADOPTERS.md
  * Add ADOPTERS.md
  * Start an adopters file
  * Regenerate table for CLIs
  * Fix e2e tests due to new quiet flag
  * Include fix for dagger on Windows
  * Add quiet flag for downloading apps
  * Add dagger tool as a downloadable package
  * Support Mac M1 environment for installing kubeseal
  * Show that arkade needs your support
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.18:
  * Fix docker-compose binary
  * Fix docker-compose and unpin version
  * Bump github.com/spf13/cobra from 1.3.0 to 1.4.0
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.17:
  * Upgrade Grafana to 6.24.1
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.16:
  * Update metrics-server chart location
  * Update ISSUE_TEMPLATE.md
  * fix: update of-loki repo url
  * Add `sops` to downloadable tools in `arkade get`
  * Pin a fix version number for hostctl tests.
  * Move sponsorship link up
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.15:
  * feat: add inlets PRO client app to arkade
  * Update traefik helm chart to the new one (since v2.2)
  * reset base and add mkcert to arkade get
  * Refactor + fix outdated kube-state-metrics charts
  * Give URL for Grafana port-forward
  * Make e2e tests verbose for logs
  * Add URL checker
  * Fix kubestr template
  * Fix k10tools template
  * Fixes: #add kubecm to arkade get
  * Fix k3d owner
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.14:
  * Remove Version property from kubectx tool to allow dynamic versioning
  * Add hostctl tool to `arkade get`
  * Update kubeseal template
  * fix: update loki helm chart repo
  * Update Linkerd2 version
  * Fix for krew test
  * Move app list down, to show examples instead
  * Update .DEREK.yml
  * Update .DEREK.yml
  * Fix kubectl template for arm64
  * feat: add vCluster CLI
  * Bump github.com/spf13/cobra from 1.2.1 to 1.3.0
  * Update natscli download URL
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.13:
  * :sparkles: Add new tools: ekstctl
  * Add Apple M1 binary
  * Use Go 1.17 in GitHub Actions
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.8.12:
  * Update KinD tool to fetch right version for Apple M1
  * fix: Fix version of kustomize
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.11:
  * Fixed k3d binary template for ming os target
  * Update Portainer app to use helm chart.
  * Update README.md
  * Fix k10multicluster app
  * Fix variable in help message for k10
  * Fix for prometheus flag in K10 app
* Tue Jan  4 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.16 or higher
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.10:
  * Update spacing on app
  * Prevent kanister installation on ARM clusters
  * Update README for 52 apps
  * added kanister app
  * Update 40 charts to 48
  * Reformat testimonials
  * Reduce depth of ToC for README
  * feature: add clusterctl tool to arkade
  * Fix inlets pro download link for arm64 darwin with test case
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.9:
  * Fix kube-bench download
  * Added missing test cases for terraform and packer
  * Fix `packer` arm64 install
  * Fix `terraform` arm64 install
  * feat: add waypoint app to arkade
  * Fix domain and ip settings for GitLab app
  * feat: add prometheus to arkade
  * Update links to arkade's down contributing guide
  * Give arkade its own, simpler contribution guide.
  * Build badge updated with Github CI link
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.8:
  * Fix issue blocking use of Apple M1
  * feat: Add waypoint cli to arkade
  * Add missing help / examples for os/arch flags in get command
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.7:
  * fix: update krew binary download
  * Support --arch and --os flags for arkade get
  * Rename flags for inlets-operator
  * Added GitHub Actions build status using workflow name
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.6:
  * Fix docker registry ingress app for k8s 1.22
  * Add new-line after arkade get completes
  * Update istio app version
  * Bump version of cert-manager to v1.5.4
  * Update README.md
  * kubectl: update kubectl version to the one that supports arm64
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.5:
  * Add dry-run flag for preflight command
  * Add preflight command
  * Add line break after post installation msg
  * Add tests for DownloadURLs
  * Update version overwriting in tool check
  * Added CockroachDB to install command, with arm install prevention.
  * Update check for tools existence
  * Refactor and add tests for post download msg templates
  * Add multi-tool download support
  * Rename flag for OIDC connector for openfaas
  * Refactoring a unit test for flags
  * Add rollout status command to block until ready
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.4:
  * Update usage message for install command
  * Return an error in case of an unknown app to install command
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.3:
  * Add flags for Prometheus, EULA and clusterName
  * Add Kasten to README
  * Update examples and long message
  * Update message for info on k10
  * Add app and info message for k10 app
  * Add k10 app to arkade
  * Bump golang.org/x/mod from 0.5.0 to 0.5.1
  * Move from io/ioutil to io and os package
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.2:
  * Add devspace, tilt, autok3s and k3s as downloads
  * remove version, it will fetch the latest available
  * Update cosign to v1.2.0
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.1:
  * feat: add kubescape support
  * feat: add GoReleaser CLI support
  * Added code to prevent arm deployment
  * Added official metallb
  * Add dive tool
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.8.0:
  * Update tests for dynamic version apps
  * Convert some apps to BinaryTemplate and latest versions
  * Fix for downloading krew
  * Add plain list output for tools
  * Enable dynamic versions for #510
  * Update flux CLI to 0.16.2
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.29:
  * Update README / docs for arkade get with @ symbol
  * Allow @ syntax to specify version flag in arkade get
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.28:
  * Bump golang.org/x/mod from 0.4.2 to 0.5.0
  * Update argocd-autopilot version
  * Add tfsec to arkade
  * Remove duplicate apps
  * Add a ToC
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.27:
  * Add command to generate markdown table for apps
  * Add developer workflow
  * Add rekor CLI fixes #488
  * Add cassandra app
  * Fix formatting in rabbitmq
  * Add rabbitmq app
  * Rename kanister to kanctl
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.26:
  * Add documentation updates to PR template
  * Print out the number of apps and CLIs
  * Update lists of apps
  * Add quotes
  * Add CLI tools for K10 project
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.25:
  * cosign: update tool to use release 1.0.0
  * Add Kyverno to arkade
  * Update .DEREK.yml
  * Add equinix metal-cli
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.24:
  * Add Cosign CLI to arkade
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.23:
  * Bump gh CLI version
  * gofmting
  * adding jq cli tool
  * Add k0s and k0sctl binary to the tools list to make it downloadable by using 'arkade get ...' command
  * Apply go fmt
  * Use text/template instead of html/template for binary url
  * Add porter CLI to arkade
  * Add check for Intel only to Jenkins app
  * fix: support ingress in k8s 1.22+ for registry ingress app
  * fix: support ingress on k8s 1.22+
  * Update domain for downloads
  * Add Packet CLI (aka Equinix Metal CLI) to arkade
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.22:
  * Add kgctl
  * Confluent Kafka added to supported applications
  * Resolve go.sum conflicts
  * Update to Go 1.16 for arkade
  * fix version not used in Binarytemplate
  * Add kubetail CLI
  * pkg/get: fix typos in tests
  * Update ISSUE_TEMPLATE.md
  * Update PULL_REQUEST_TEMPLATE.md
  * Add nova cli
  * influx CLI added
  * Bump github.com/spf13/cobra from 1.1.3 to 1.2.1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.21:
  * Fix values names for kafka-connector
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.20:
  * Fix kubectl incorrect download URL version
  * Fix description for helm on ASCII table.
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.19:
  * Fix download for armv6l of inlets PRO
  * Add output mode for tool table
  * Add description tag to tool argocd-autopilot
  * Update kubebuilder 3.1.0
  * Add ASCII table with description for CLI tools
  * Add argocd-autopilot 0.2.1
  * Update terraform 1.0.0
  * Create test table for kubectl tool
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.18:
  * update tests based on review feeback
  * add initial tests for inletsoperator_app
  * Fix test for ARM64 download
  * Fix download template URLs
  * k9s version upgrade to v0.24.10
  * makefile: more specific windows/amd64 target
  * Add test for kubectl on arm64
  * tools: fix get kubectl logic for arm64 downloads
  * Add polaris CLI
  * Bump the nats cli version to 0.23
  * Istio updated to 1.10.0
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.17:
  * Continue to use darwin x86 for M1
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.7.16:
  * Fix #409 for arm64 usage
  * Extract local variable
  * Update flag help message to show default
  * Default the inlets-pro license location
  * Update README.md
* Sun May 23 2021 kastl@b1-systems.de
- Update to version 0.7.15:
  * fix for --function-pull-policy flag at install command for openfaas
  * add flux v2 CLI supporrt
  * trivy CLI added
  * Update influxdb install message
  * Add Rancher's kim to arkade get
  * Add influxdb to arkade
  * feat(inlets-pro): support installation of inlets-pro CLI
  * feat(docker-compose): docker-compose version upgraded from 1.27.4 to 1.29.1
  * tools: add tkn (tekton cli)
  * Bump github.com/cheggaaa/pb/v3 from 3.0.7 to 3.0.8
* Sun May 23 2021 kastl@b1-systems.de
- Update to version 0.7.15:
  * Extract local variable
  * Update flag help message to show default
  * Default the inlets-pro license location
  * Update README.md
  * fix for --function-pull-policy flag at install command for openfaas
  * add flux v2 CLI supporrt
  * trivy CLI added
  * Update influxdb install message
  * Add Rancher's kim to arkade get
  * Add influxdb to arkade
* Sun May 23 2021 Johannes Kastl <kastl@b1-systems.de>
- inital version of package arkade
